@@ -2,6 +2,7 @@ import json
 import os
 import sys
 
+from chromadb.api.models.AsyncCollection import AsyncCollection
 from chromadb.api.types import IncludeEnum
 from chromadb.errors import InvalidCollectionException, InvalidDimensionException
 
@@ -14,6 +15,61 @@ from vectorcode.common import (
 )
 
 
+async def get_query_result_files(
+    collection: AsyncCollection, configs: Config
+) -> list[str]:
+    query_chunks = []
+    if configs.query:
+        chunker = StringChunker(configs.chunk_size, configs.overlap_ratio)
+        for q in configs.query:
+            query_chunks.extend(chunker.chunk(q))
+
+    configs.query_exclude = [
+        expand_path(i, True)
+        for i in await expand_globs(configs.query_exclude)
+        if os.path.isfile(i)
+    ]
+    if (await collection.count()) == 0:
+        print("Empty collection!", file=sys.stderr)
+        return []
+    try:
+        num_query = await collection.count()
+        if configs.query_multiplier > 0:
+            num_query = min(
+                int(configs.n_result * configs.query_multiplier),
+                await collection.count(),
+            )
+        if len(configs.query_exclude):
+            filtered_files = {"path": {"$nin": configs.query_exclude}}
+        else:
+            filtered_files = None
+        results = await collection.query(
+            query_texts=query_chunks,
+            n_results=num_query,
+            include=[
+                IncludeEnum.metadatas,
+                IncludeEnum.distances,
+                IncludeEnum.documents,
+            ],
+            where=filtered_files,
+        )
+    except IndexError:
+        # no results found
+        return []
+
+    if configs.reranker is None:
+        from .reranker import NaiveReranker
+
+        aggregated_results = NaiveReranker(configs).rerank(results)
+    else:
+        from .reranker import CrossEncoderReranker
+
+        aggregated_results = CrossEncoderReranker(
+            configs, query_chunks, configs.reranker, **configs.reranker_params
+        ).rerank(results)
+    return aggregated_results
+
+
 async def query(configs: Config) -> int:
     client = await get_client(configs)
     try:
@@ -41,59 +97,9 @@ async def query(configs: Config) -> int:
     if not configs.pipe:
         print("Starting querying...")
 
-    query_chunks = []
-    if configs.query:
-        chunker = StringChunker(configs.chunk_size, configs.overlap_ratio)
-        for q in configs.query:
-            query_chunks.extend(chunker.chunk(q))
-
-    configs.query_exclude = [
-        expand_path(i, True)
-        for i in await expand_globs(configs.query_exclude)
-        if os.path.isfile(i)
-    ]
-    if (await collection.count()) == 0:
-        print("Empty collection!", file=sys.stderr)
-        return 1
-    try:
-        num_query = await collection.count()
-        if configs.query_multiplier > 0:
-            num_query = min(
-                int(configs.n_result * configs.query_multiplier),
-                await collection.count(),
-            )
-        if len(configs.query_exclude):
-            filtered_files = {"path": {"$nin": configs.query_exclude}}
-        else:
-            filtered_files = None
-        results = await collection.query(
-            query_texts=query_chunks,
-            n_results=num_query,
-            include=[
-                IncludeEnum.metadatas,
-                IncludeEnum.distances,
-                IncludeEnum.documents,
-            ],
-            where=filtered_files,
-        )
-    except IndexError:
-        # no results found
-        return 0
-
     structured_result = []
 
-    if configs.reranker is None:
-        from .reranker import NaiveReranker
-
-        aggregated_results = NaiveReranker(configs).rerank(results)
-    else:
-        from .reranker import CrossEncoderReranker
-
-        aggregated_results = CrossEncoderReranker(
-            configs, query_chunks, configs.reranker, **configs.reranker_params
-        ).rerank(results)
-
-    for path in aggregated_results:
+    for path in await get_query_result_files(collection, configs):
         if os.path.isfile(path):
             with open(path) as fin:
                 document = fin.read()
